<?php

App::import('Vendor', 'Dompdf', array('file' =>'Dompdf'.DS.'autoload.inc.php'));

use Dompdf\Dompdf;

class PdfComponent extends Object 
{ 
    public function compressContent($html)
    {
        $replace = array(
            '/\>[^\S ]+/s'   => '>',
            '/[^\S ]+\</s'   => '<',
            '/([\t ])+/s'  => ' ',
            '/^([\t ])+/m' => '',
            '/([\t ])+$/m' => '',
            '~//[a-zA-Z0-9 ]+$~m' => '',
            '/[\r\n]+([\t ]?[\r\n]+)+/s'  => "\n",
            '/\>[\r\n\t ]+\</s'    => '><',
            '/}[\r\n\t ]+/s'  => '}',
            '/}[\r\n\t ]+,[\r\n\t ]+/s'  => '},',
            '/\)[\r\n\t ]?{[\r\n\t ]+/s'  => '){',
            '/,[\r\n\t ]?{[\r\n\t ]+/s'  => ',{',
            '/\),[\r\n\t ]+/s'  => '),',
            '~([\r\n\t ])?([a-zA-Z0-9]+)="([a-zA-Z0-9_/\\-]+)"([\r\n\t ])?~s' => '$1$2=$3$4',
        );
        $html = preg_replace(array_keys($replace), array_values($replace), $html);
    
        $remove = array(
            '</option>', '</li>', '</dt>', '</dd>', '</tr>', '</th>', '</td>'
        );
        $html = str_ireplace($remove, '', $html);
        
        return $html;   
    }
    
    public function PdfReport($html, $file_name, $paper_size = '', $redirect = false, $generate_file_only = false)
    {
        if($paper_size == '')
        {
            $CommonSetting = ClassRegistry::init('CommonSetting');
            $settings = $CommonSetting->getSettings();
            $paper_size = $settings->letterhead_paper_size;
        }
        
        ini_set("memory_limit", "128M");
        $dompdf = new Dompdf();
        $dompdf->set_option('isHtml5ParserEnabled', true);
        $dompdf->set_option('isPhpEnabled', true);
        $dompdf->set_base_path(WWW_ROOT);
        //$html = $this->compressContent($html);
        $dompdf->loadHtml($html);
        $dompdf->setPaper($paper_size, 'portrait');
        $dompdf->render();
        
        if($generate_file_only)
        {
            $pdf_file = WWW_ROOT.'documents'.DS.'pdf'.DS.$file_name;
            file_put_contents($pdf_file, $dompdf->output());
            
            return array('folder' => 'pdf', 'file_name' => $file_name);
        }
        
        if($redirect)
        {
            header('Content-type: application/pdf');
            header('Content-Disposition: inline; filename="' . $file_name . '"');
            header('Content-Transfer-Encoding: binary');
            header('Accept-Ranges: bytes');
        
            $pdf_file = WWW_ROOT.'documents'.DS.'pdf'.DS.$file_name;
            file_put_contents($pdf_file, $dompdf->output());
            
            $file_name = str_replace(' ', '%20', $file_name);
            $file_name = str_replace('#', '%23', $file_name);
            
            $http_protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off' || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
            
            $file_url = $http_protocol . $_SERVER['HTTP_HOST'] . Router::url('/') . 'documents/pdf/' . $file_name;
            
            header('Location:' . $file_url);
        }
        else
        {
            return $dompdf->stream($file_name, array("Attachment" => false));
        }
    }
}


?>